@@ -6,23 +6,28 @@
 use highlight;
 
 #get a generator instance (for HTML output)
-my $gen = highlightc::CodeGenerator_getInstance(0);
+my $gen = highlight::CodeGenerator::getInstance($highlight::CodeGenerator::HTML);
+ 
+my $dir = new highlight::DataDir();
 
+$dir->searchDataDir("");
+my $themepath=$dir->getThemePath("seashell.theme");
+my $langpath=$dir->getLangPath("c.lang");
 
 #initialize the generator with a colour theme and the language definition
-$gen->initTheme("/usr/share/highlight/themes/kwrite.style");
-$gen->initLanguage("/usr/share/highlight/langDefs/c.lang");
+$gen->initTheme($themepath);
+$gen->loadLanguage($langpath);
 
 #set some parameters
 $gen->setIncludeStyle(1);
 $gen->setEncoding("ISO-8859-1");
 
 #get output string
-my $output=$gen->generateCString("int main(int argc, char **argv) {\n".
+my $output=$gen->generateString("int main(int argc, char **argv) {\n".
                            " HighlightApp app;\n".
                            " return app.run(argc, argv);\n".
                            "}\n");
 print $output;
 
 # clear the instance
-highlightc::CodeGenerator_deleteInstance();
+highlight::CodeGenerator::deleteInstance($gen);
