@@ -132,7 +132,7 @@ bool HLCmdLineApp::printInstalledLanguages()
     for ( unsigned int i=0;i< filePaths.size(); i++ )
     {
         Diluculum::LuaState ls;
-	highlight::SyntaxReader::initLuaState(ls, filePaths[i]);
+	highlight::SyntaxReader::initLuaState(ls, filePaths[i],"");
         ls.doFile(filePaths[i]);
         desc = ls["Description"].value().asString();
         suffix = ( filePaths[i] ).substr ( directory.length() ) ;
@@ -224,6 +224,9 @@ void HLCmdLineApp::printConfigInfo ( const string& configFile )
     cout << endl;
 }
 
+/*
+ * 
+ * broken:
 string HLCmdLineApp::getFileSuffix ( const string &fileName )
 {
     size_t ptPos=fileName.rfind ( "." );
@@ -233,6 +236,14 @@ string HLCmdLineApp::getFileSuffix ( const string &fileName )
         return fileName.substr ( ptPos+1, fileName.length() );
     else
         return "";
+}*/
+
+string HLCmdLineApp::getFileSuffix(const string& fileName)
+{
+  size_t ptPos=fileName.rfind(".");
+  size_t psPos = fileName.rfind ( Platform::pathSeparator );
+  return (ptPos == string::npos || (psPos!=string::npos && psPos>ptPos)) ? "" : fileName.substr(ptPos+1,
+                                        fileName.length());
 }
 
 bool HLCmdLineApp::loadFileTypeConfig ( const string& name, StringMap* extMap, StringMap* shebangMap )
@@ -243,12 +254,13 @@ bool HLCmdLineApp::loadFileTypeConfig ( const string& name, StringMap* extMap, S
 
     try {
         Diluculum::LuaState ls;
-        ls.doFile (confPath);
+        Diluculum::LuaValueList ret= ls.doFile (confPath);
+
         int idx=1;
         string langName;
 	Diluculum::LuaValue mapEntry;
         while ((mapEntry = ls["FileMapping"][idx].value()) !=Diluculum::Nil) {
-            langName = mapEntry["Lang"].asString();
+            langName = mapEntry["Lang"].asString(); 
             if (mapEntry["Extensions"] !=Diluculum::Nil) {
                 int extIdx=1;
                 while (mapEntry["Extensions"][extIdx] !=Diluculum::Nil) {
@@ -260,6 +272,7 @@ bool HLCmdLineApp::loadFileTypeConfig ( const string& name, StringMap* extMap, S
             }
             idx++;
         }
+
     }
     catch (Diluculum::LuaError err) {
         cerr <<err.what()<<"\n";
@@ -359,9 +372,15 @@ string HLCmdLineApp::analyzeFile ( const string& file )
 
 string HLCmdLineApp::guessFileType ( const string& suffix, const string &inputFile )
 {
-    if (suffix.empty()) return analyzeFile ( inputFile );
+    string lcSuffix = StringTools::change_case(suffix);
+
+    string fileType = (extensions.count(lcSuffix)) ? extensions[lcSuffix] : lcSuffix ;
+    if (!fileType.empty()) return fileType;
+    return analyzeFile(inputFile);
+    
+    /*if (suffix.empty()) return analyzeFile ( inputFile );
     string lcSuffix = StringTools::change_case ( suffix );
-    return ( extensions.count ( lcSuffix ) ) ? extensions[lcSuffix] : lcSuffix ;
+    return ( extensions.count ( lcSuffix ) ) ? extensions[lcSuffix] : lcSuffix ;*/
    // if ( !fileType.empty() ) return fileType;
    // return "";
 }
@@ -461,11 +480,11 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
     generator->setLineNumberWidth ( options.getNumberWidth() );
     generator->setStartingNestedLang( options.getStartNestedLang());
     generator->disableTrailingNL(options.disableTrailingNL());
+    generator->setPluginReadFile(options.getPluginReadFilePath());
 
+    
     bool styleFileWanted = !options.fragmentOutput() || options.styleOutPathDefined();
 
-
-
     const  vector <string> pluginFileList=options.getPluginPaths();
     for (unsigned int i=0;i<pluginFileList.size();i++){
     if ( !generator->initPluginScript(pluginFileList[i]) )
