@@ -2,7 +2,7 @@
                           codegenerator.cpp  -  description
                              -------------------
     begin                : Die Jul 9 2002
-    copyright            : (C) 2002-2010 by Andre Simon
+    copyright            : (C) 2002-2012 by Andre Simon
     email                : andre.simon1@gmx.de
  ***************************************************************************/
 
@@ -57,12 +57,12 @@ namespace highlight
 	const string CodeGenerator::STY_NAME_STR="str";
 	const string CodeGenerator::STY_NAME_NUM="num";
 	const string CodeGenerator::STY_NAME_SLC="slc";
-	const string CodeGenerator::STY_NAME_COM="com" ;
-	const string CodeGenerator::STY_NAME_ESC="esc" ;
-	const string CodeGenerator::STY_NAME_DIR="ppc" ;//preprocessor
-	const string CodeGenerator::STY_NAME_DST="pps";//preprocessor string
+	const string CodeGenerator::STY_NAME_COM="com";
+	const string CodeGenerator::STY_NAME_ESC="esc";
+	const string CodeGenerator::STY_NAME_DIR="ppc"; //preprocessor
+	const string CodeGenerator::STY_NAME_DST="pps"; //preprocessor string
 	const string CodeGenerator::STY_NAME_LIN="lin";
-	const string CodeGenerator::STY_NAME_SYM="opt" ;//operator
+	const string CodeGenerator::STY_NAME_SYM="opt"; //operator
 
 	CodeGenerator * CodeGenerator::getInstance ( OutputType type )
 	{
@@ -151,7 +151,7 @@ namespace highlight
 	bool CodeGenerator::initTheme ( const string& themePath )
 	{
 		this->themePath=themePath;
-		bool loadOK = docStyle.load ( themePath );
+		bool loadOK = docStyle.load ( themePath, outputType );
 		initOutputTags();
 		return loadOK;
 	}
@@ -212,6 +212,11 @@ namespace highlight
 		styleOutputPath = path;
 	}
 
+	void CodeGenerator::setPluginReadFile ( const string& path )
+	{
+		pluginReadFile = path;
+	}
+	
 	const string&  CodeGenerator::getStyleInputPath()
 	{
 		return styleInputPath;
@@ -447,7 +452,6 @@ namespace highlight
 			}
 			lineIndex=0;
 			++lineNumber;
-			//line=StringTools::trimRight ( line );
 			matchRegex ( line );
 
 			return ( eof ) ?'\0':'\n';
@@ -508,12 +512,10 @@ namespace highlight
 					if ( !currentKeywordClass && regexGroups[oldIndex].state==KEYWORD )
 						currentKeywordClass = regexGroups[oldIndex].kwClass;
 					return validateState(( currentKeywordClass ) ? KEYWORD : STANDARD, oldState, currentKeywordClass);
-					//return ( currentKeywordClass ) ? KEYWORD : STANDARD;
 				}
 				else
 				{
 					return validateState(regexGroups[oldIndex].state, oldState, 0);
-					//return regexGroups[oldIndex].state;
 				}
 			}
 		}
@@ -559,16 +561,40 @@ namespace highlight
 	{
 		if ( flushWhiteSpace ) flushWs();
 
-		if ( addMetaInfo && tagsEnabled )
+		if ( addMetaInfo && tagsEnabled ) // TODO replace ctags parser by plugin (requires file input)
 		{
 			bool insertMetaInfo=metaInfo.tagExists ( token );
 			if ( insertMetaInfo ) *out<<getMetaInfoOpenTag ( metaInfo.getTagInfo ( token ) );
+
 			maskString ( *out, StringTools::change_case ( token, tcase ) );
+			
 			if ( insertMetaInfo ) *out<<getMetaInfoCloseTag();
 		}
 		else
 		{
-			maskString ( *out, StringTools::change_case ( token, tcase ) );
+		      if (currentSyntax->getDecorateFct()){
+
+			  Diluculum::LuaValueList params;
+			  params.push_back(Diluculum::LuaValue(token));
+			  params.push_back(Diluculum::LuaValue(currentState));
+			  params.push_back(Diluculum::LuaValue(currentKeywordClass));
+
+			  Diluculum::LuaValueList res=
+			    currentSyntax->getLuaState()->call ( *currentSyntax->getDecorateFct(),
+						    params,"getDecorateFct call")  ;
+
+			  if (res.size()==1){
+			    *out<<res[0].asString();
+			  } else {
+			     maskString ( *out, StringTools::change_case ( token, tcase ) ); 
+			  }
+			  
+			} else {
+
+			    maskString ( *out, StringTools::change_case ( token, tcase ) );
+			}
+		  
+			//maskString ( *out, StringTools::change_case ( token, tcase ) );
 		}
 		token.clear();
 	}
@@ -658,7 +684,7 @@ namespace highlight
 			    result=LOAD_OK;
 			} else {
 			    currentSyntax=new SyntaxReader();
-			    result=currentSyntax->load(langDefPath);
+			    result=currentSyntax->load(langDefPath, pluginReadFile, outputType);
 			    syntaxReaders[langDefPath]=currentSyntax;
 			}
 
@@ -706,16 +732,16 @@ namespace highlight
 		// Magic configuration of "file"
 		// This is intended for web plugins - only check filetypes often found in the net
 		char magic_gif[]    = {'G','I','F','8', 0};
-		char magic_png[]    = {0x89,'P','N','G', 0};
-		char magic_java[]   = {0xCA,0xFE,0xBA,0xBE, 0};
-		char magic_jpeg[]   = {0xFF,0xD8,0xFF, 0};
+		char magic_png[]    = {'\x89','P','N','G', 0};
+		char magic_java[]   = {'\xCA','\xFE','\xBA','\xBE', 0};
+		char magic_jpeg[]   = {'\xFF','\xD8','\xFF', 0};
 		char magic_bmp[]    = {'B','M', 0};
 		char magic_pdf[]    = {'%','P','D','F', 0};
-		char magic_utf8[]   = {0xEF,0xBB,0xBF,0};
+		char magic_utf8[]   = {'\xEF','\xBB','\xBF',0};
 		char magic_rar[]    = {'R','a','r','!', 0};
-		char magic_zip[]    = {'P','K',0x03,0x04, 0};
+		char magic_zip[]    = {'P','K','\x03','\x04', 0};
 		char magic_ace[]    = {'*','*','A','C','E','*','*', 0};
-		char magic_tgz[]    = {0x8b,0x1f, 0x00, 0x08, 0};
+		char magic_tgz[]    = {'\x8b','\x1f', '\x00', '\x08', 0};
 		char magic_bzip[]   = {'B','Z', 0};
 
 		char* magic_table[] = {magic_utf8,
@@ -1576,7 +1602,7 @@ namespace highlight
 
 	bool CodeGenerator::printExternalStyle ( const string &outFile )
 	{
-		if ( !includeStyleDef /*&& currentSyntax->highlightingEnabled()*/ )
+		if ( !includeStyleDef )
 		{
 			ostream *cssOutFile = ( outFile.empty() ? &cout :new ofstream ( outFile.c_str() ) );
 			if ( !cssOutFile->fail() )
@@ -1628,6 +1654,13 @@ namespace highlight
 					<< "." << styleCommentClose << "\n";
 			}
 		}
+
+		string injections=docStyle.getInjections();
+		if (!injections.empty()){
+		   		ostr 	<< "\n" << styleCommentOpen
+					<< " Plug-in theme injections: " <<styleCommentClose << "\n";
+				ostr << injections<<"\n";
+		}
 		return ostr.str();
 	}
 
