@@ -57,7 +57,7 @@ namespace highlight
 			*out << "\\" << this->getBaseFont() << "\n" ;
 		else
 			*out << "\\ttfamily\n";
-		if ( ! this->getBaseFontSize().empty() )
+		if ( ! this->getBaseFontSize().empty() && this->getBaseFontSize()!="10")
 			*out << "\\" << this->getBaseFontSize() << "\n" ;
 		if ( disableBabelShortHand )
 			*out << "\\shorthandoff{\"}\n";
@@ -95,7 +95,7 @@ namespace highlight
 			os << "\\usepackage{marvosym}\n";
 		}
 
-		if ( langInfo.highlightingEnabled() )
+		if ( currentSyntax->highlightingEnabled() )
 		{
 			if ( includeStyleDef )
 			{
@@ -163,18 +163,19 @@ namespace highlight
 
 
 	void LatexGenerator::initOutputTags(){
-		openTags.push_back ( "\\hlstd{" );
-		openTags.push_back ( "\\hlstr{" );
-		openTags.push_back ( "\\hlnum{" );
-		openTags.push_back ( "\\hlslc{" );
-		openTags.push_back ( "\\hlcom{" );
-		openTags.push_back ( "\\hlesc{" );
-		openTags.push_back ( "\\hldir{" );
-		openTags.push_back ( "\\hldstr{" );
-		openTags.push_back ( "\\hlline{" );
-		openTags.push_back ( "\\hlsym{" );
 
-		for ( int i=0;i<NUMBER_BUILTIN_STATES; i++ )
+		openTags.push_back ( "\\hl"+STY_NAME_STD+"{" );
+		openTags.push_back ( "\\hl"+STY_NAME_STR+"{" );
+		openTags.push_back ( "\\hl"+STY_NAME_NUM+"{" );
+		openTags.push_back ( "\\hl"+STY_NAME_SLC+"{" );
+		openTags.push_back ( "\\hl"+STY_NAME_COM+"{" );
+		openTags.push_back ( "\\hl"+STY_NAME_ESC+"{" );
+		openTags.push_back ( "\\hl"+STY_NAME_DIR+"{" );
+		openTags.push_back ( "\\hl"+STY_NAME_DST+"{" );
+		openTags.push_back ( "\\hl"+STY_NAME_LIN+"{" );
+		openTags.push_back ( "\\hl"+STY_NAME_SYM+"{" );
+
+		for (unsigned int i=0;i<NUMBER_BUILTIN_STATES; i++ )
 		{
 			closeTags.push_back ( "}" );
 		}
@@ -291,7 +292,7 @@ namespace highlight
 
 	string LatexGenerator::getKeywordOpenTag ( unsigned int styleID )
 	{
-		return "\\hl"+langInfo.getKeywordClasses() [styleID]+"{";
+		return "\\hl"+currentSyntax->getKeywordClasses() [styleID]+"{";
 	}
 
 	string LatexGenerator::getKeywordCloseTag ( unsigned int styleID )
@@ -308,11 +309,11 @@ namespace highlight
 			os << getAttributes ( STY_NAME_NUM, docStyle.getNumberStyle() );
 			os << getAttributes ( STY_NAME_ESC, docStyle.getEscapeCharStyle() );
 			os << getAttributes ( STY_NAME_STR, docStyle.getStringStyle() );
-			os << getAttributes ( STY_NAME_DST, docStyle.getDirectiveStringStyle() );
+			os << getAttributes ( STY_NAME_DST, docStyle.getPreProcStringStyle() );
 			os << getAttributes ( STY_NAME_SLC, docStyle.getSingleLineCommentStyle() );
 			os << getAttributes ( STY_NAME_COM, docStyle.getCommentStyle() );
-			os << getAttributes ( STY_NAME_DIR, docStyle.getDirectiveStyle() );
-			os << getAttributes ( STY_NAME_SYM, docStyle.getSymbolStyle() );
+			os << getAttributes ( STY_NAME_DIR, docStyle.getPreProcessorStyle() );
+			os << getAttributes ( STY_NAME_SYM, docStyle.getOperatorStyle() );
 			os << getAttributes ( STY_NAME_LIN, docStyle.getLineStyle() );
 
 			KeywordStyles styles = docStyle.getKeywordStyles();
