@@ -49,8 +49,22 @@ int SyntaxReader::luaAddKeyword (lua_State *L) {
     lua_pushboolean(L, retVal);
     return 1;
 }
-
-
+/*
+int SyntaxReader::luaReadFile (lua_State *L) {
+    std::string buf;
+    if (lua_gettop(L)==1){
+      	const char*filename=lua_tostring(L, 1);
+	std::string line;
+	std::ifstream in(filename);
+	while(std::getline(in,line)){
+	  buf += line;
+	  buf += "\n";
+	}
+    }
+    lua_pushstring(L, buf.c_str());
+    return 1;
+}
+*/
 const string SyntaxReader::REGEX_IDENTIFIER =
     "[a-zA-Z_]\\w*";
 
@@ -73,6 +87,7 @@ SyntaxReader::SyntaxReader() :
         rawStringPrefix(0),
         continuationChar(0),
         validateStateChangeFct(NULL),
+        decorateFct(NULL),
         luaState(NULL)
 {
 
@@ -80,14 +95,12 @@ SyntaxReader::SyntaxReader() :
 
 SyntaxReader::~SyntaxReader()
 {
-  // cerr << "reset destr \n";
-    //reset();
-
     for ( vector<RegexElement*>::iterator it=regex.begin(); it!=regex.end();it++ )
     {
         delete *it;
     }
     if (validateStateChangeFct) delete validateStateChangeFct;
+    if (decorateFct) delete decorateFct;
 
     if (luaState) delete luaState;
 
@@ -137,11 +150,14 @@ bool SyntaxReader::readFlag(const Diluculum::LuaVariable& var) {
 }
 
 
-void  SyntaxReader::initLuaState(Diluculum::LuaState& ls, const string& langDefPath){
+void  SyntaxReader::initLuaState(Diluculum::LuaState& ls, const string& langDefPath, const string& pluginReadFilePath, OutputType type ){
           // initialize Lua state with variables which can be used within scripts
         string::size_type Pos = langDefPath.find_last_of ( Platform::pathSeparator );
         ls["HL_LANG_DIR"] =langDefPath.substr ( 0, Pos+1 );
 
+	ls["HL_INPUT_FILE"] = pluginReadFilePath;
+	ls["HL_OUTPUT"] = type;
+	
         ls["Identifiers"]=REGEX_IDENTIFIER;
         ls["Digits"]=REGEX_NUMBER;
 
@@ -169,6 +185,17 @@ void  SyntaxReader::initLuaState(Diluculum::LuaState& ls, const string& langDefP
 	ls["HL_IDENTIFIER_BEGIN"]=IDENTIFIER_BEGIN;
 	ls["HL_IDENTIFIER_END"]=IDENTIFIER_END;
 	ls["HL_UNKNOWN"]=_UNKNOWN;
+	ls["HL_FORMAT_HTML"]=HTML;
+	ls["HL_FORMAT_XHTML"]=XHTML;
+	ls["HL_FORMAT_TEX"]=TEX;
+	ls["HL_FORMAT_LATEX"]=LATEX;
+	ls["HL_FORMAT_RTF"]=RTF;
+	ls["HL_FORMAT_ANSI"]=ANSI;
+	ls["HL_FORMAT_XTERM256"]=XTERM256;
+	ls["HL_FORMAT_HTML32"]=HTML32;
+	ls["HL_FORMAT_SVG"]=SVG;
+	ls["HL_FORMAT_BBCODE"]=BBCODE;
+	
 }
 
 
@@ -178,12 +205,8 @@ void SyntaxReader::addKeyword(unsigned int groupID, const string& kw){
   }
 }
 
-LoadResult SyntaxReader::load ( const string& langDefPath, bool clear )
+LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginReadFilePath, OutputType outputType, bool clear )
 {
-  /*  if ( clear )  {
-     cerr << "reset load \n";
-      reset();
-    }*/
 
     currentPath=langDefPath;
     disableHighlighting=false;
@@ -198,9 +221,10 @@ LoadResult SyntaxReader::load ( const string& langDefPath, bool clear )
 	luaState=new Diluculum::LuaState();
 
 	Diluculum::LuaState& ls=*luaState;
-	initLuaState(ls, langDefPath);
-
+	initLuaState(ls, langDefPath, pluginReadFilePath, outputType);
+  //     ls["HL_INPUT_FILE"]="testbla";
 	lua_register (ls.getState(),"AddKeyword",luaAddKeyword);
+	//lua_register (ls.getState(),"ReadFile",luaReadFile);
 
 	SyntaxReader **s = (SyntaxReader **)lua_newuserdata(ls.getState(), sizeof(SyntaxReader *));
 	*s=this;
@@ -447,6 +471,9 @@ LoadResult SyntaxReader::load ( const string& langDefPath, bool clear )
         if (globals.count("OnStateChange")) {
             validateStateChangeFct=new Diluculum::LuaFunction(ls["OnStateChange"].value().asFunction());
         }
+        if (globals.count("Decorate")) {
+            decorateFct=new Diluculum::LuaFunction(ls["Decorate"].value().asFunction());
+        }
 
     } catch (Diluculum::LuaError err) {
         luaErrorMsg = string(err.what());
@@ -455,31 +482,6 @@ LoadResult SyntaxReader::load ( const string& langDefPath, bool clear )
     return LOAD_OK;
 }
 
-/*
-void SyntaxReader::reset()
-{
-    keywords.clear();
-    keywordClasses.clear();
-    delimiterDistinct.clear();
-    langDesc.clear();
-    ignoreCase= false;
-    allowNestedComments= reformatCode = false;
-    rawStringPrefix = continuationChar = '\0';
-    disableHighlighting=false;
-    regex.clear();
-    regexErrorMsg.clear();
-
-    // TODO eigene methode
-    for ( vector<RegexElement*>::iterator it=regex.begin(); it!=regex.end();it++ )
-    {
-        delete *it;
-    }
-    if (validateStateChangeFct) delete validateStateChangeFct; validateStateChangeFct=NULL;
-
-    if (luaState) delete luaState; luaState=NULL;
-}
-*/
-
 string SyntaxReader::getNewPath(const string& lang) {
     string::size_type Pos = currentPath.find_last_of ( Platform::pathSeparator );
     return currentPath.substr ( 0, Pos+1 ) + lang + ".lang";
