@@ -303,7 +303,9 @@ void MainWindow::on_pbOutputDest_clicked(){
                        ui->leSVGStyleFile->text());
      settings.setValue(ui->leSVGStyleIncFile->property(name).toString(),
                        ui->leSVGStyleIncFile->text());
-
+    settings.setValue(ui->lePluginReadFilePath->property(name).toString(),
+                       ui->lePluginReadFilePath->text());
+     
      settings.setValue(ui->cbSVGEmbedStyle->property(name).toString(),
                        ui->cbSVGEmbedStyle->isChecked());
      settings.setValue(ui->cbLATEXEmbedStyle->property(name).toString(),
@@ -332,6 +334,7 @@ void MainWindow::on_pbOutputDest_clicked(){
 
  void MainWindow::readSettings()
  {
+     ui->tabIOSelection->setCurrentIndex(0); // wie default setzen?
      QSettings settings(QSettings::IniFormat, QSettings::UserScope,
                         "andre-simon.de", "highlight-gui");
 
@@ -402,7 +405,8 @@ void MainWindow::on_pbOutputDest_clicked(){
      ui->leSVGWidth->setText(settings.value(ui->leSVGWidth->property(name).toString()).toString());
      ui->leFontSize->setText(settings.value(ui->leFontSize->property(name).toString()).toString());
      ui->leHTMLCssPrefix->setText(settings.value(ui->leHTMLCssPrefix->property(name).toString()).toString());
-
+     ui->lePluginReadFilePath->setText(settings.value(ui->lePluginReadFilePath->property(name).toString()).toString());
+     
      ui->sbLineLength->setValue(settings.value(ui->sbLineLength->property(name).toString()).toInt());
      ui->sbTabWidth->setValue(settings.value(ui->sbTabWidth->property(name).toString()).toInt());
      ui->cbTEXEmbedStyle->setChecked(settings.value(ui->cbTEXEmbedStyle->property(name).toString()).toBool());
@@ -602,6 +606,7 @@ void MainWindow::applyCtrlValues(highlight::CodeGenerator* generator, bool previ
 
     generator->setPrintLineNumbers( ui->cbIncLineNo->isChecked());
     generator->setPrintZeroes(ui->cbPadZeroes->isEnabled() && ui->cbPadZeroes->isChecked());
+    generator->setPluginReadFile(ui->lePluginReadFilePath->text().toStdString());
 
 #ifdef DATA_DIR
       QString themePath = QString("%1themes/%2.theme").arg(
@@ -1093,7 +1098,6 @@ void MainWindow::on_pbTEXChooseStyleIncFile_clicked()
         selectSingleFile(ui->leTEXStyleIncFile, tr("Choose a style include file"), "*.sty");
 }
 
-
 void MainWindow::on_actionAbout_translations_triggered()
 {
     QMessageBox::information(this, tr("About providing translations"),
@@ -1204,3 +1208,8 @@ void MainWindow::on_actionDock_floating_panels_toggled(bool arg1)
 {
     ui->dockWidget->setFloating(arg1);
 }
+
+void MainWindow::on_pbPluginReadFilePath_clicked()
+{
+       selectSingleFile(ui->lePluginReadFilePath, tr("Choose a plug-in input file"), "*");
+}
