@@ -59,6 +59,7 @@ namespace highlight
 
 			string errorMsg;
 			string desc;
+			vector <string> injections;
 
 			vector<Diluculum::LuaFunction*> pluginChunks;
 
@@ -76,7 +77,7 @@ namespace highlight
 			/** load style definition
 			      \param styleDefinitionFile Style definition path
 			      \return True if successfull */
-			bool load ( const string & styleDefinitionFile );
+			bool load ( const string & styleDefinitionFile, OutputType outputType=HTML );
 
 			void addUserChunk(const Diluculum::LuaFunction& chunk){
 
@@ -93,6 +94,8 @@ namespace highlight
 			string getErrorMessage() const;
 
 			string getDescription() const { return desc;}
+			
+			string getInjections() const;
 
 			/** \return Background colour*/
 			Colour getBgColour() const;
